==> attal_0.8.orig.tar.gz: attal-0.8/i18n/ru/attal_server_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Выберете</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Старт</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Выход</translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Ошибка в сценарии</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Неверное количество подключившихся игроков</translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation>Attal - Lords of Doom (Server)</translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Ошибка сервера</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation>Невозможно прослушать сокеты.</translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Попробовать снова</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Полоска состояния</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation>Загрузить игру</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation>Сохранить игру</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation>Завершить игру</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Закончить</translation>
    </message>
</context>
</TS>

==> attal_0.9.1.orig.tar.gz: attal-0.9.1/i18n/ru/attal_server_ru.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>ChooseFileRadioButton</name>
    <message>
        <source>Choose</source>
        <translation>Выберете</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Start server</source>
        <translation>Стартовый сервер</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Хост:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
</context>
<context>
    <name>DisplayScenarii</name>
    <message>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <source>Players</source>
        <translation>Игроки</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
</context>
<context>
    <name>DisplayScenariiDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>DisplayScenarioDescription</name>
    <message>
        <source>Name: %1</source>
        <translation>Имя: %1</translation>
    </message>
    <message>
        <source>Player(s): %1</source>
        <translation>Игрок(и): %1</translation>
    </message>
    <message>
        <source>Size: %1x%2</source>
        <translation>Размер: %1x%2</translation>
    </message>
    <message>
        <source>Description: %1</source>
        <translation>Описание: %1</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Player(s): </source>
        <translation>Игрок(и):</translation>
    </message>
    <message>
        <source>Size: </source>
        <translation>Размер:</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>Описание:</translation>
    </message>
</context>
<context>
    <name>Engine</name>
    <message>
        <source>Error with scenario</source>
        <translation>Ошибка в сценарии</translation>
    </message>
    <message>
        <source>Wrong number of connected players</source>
        <translation>Неверное количество подключившихся игроков</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Unknown</source>
        <translation>Неизв</translation>
    </message>
</context>
<context>
    <name>ServerInterface</name>
    <message>
        <source>Attal - Lords of Doom (Server)</source>
        <translation>Attal - Lords of Doom (Server)</translation>
    </message>
    <message>
        <source>Server error</source>
        <translation>Ошибка сервера</translation>
    </message>
    <message>
        <source>Could not listen for sockets.</source>
        <translation>Невозможно прослушать сокеты.</translation>
    </message>
    <message>
        <source>Try again</source>
        <translation>Попробовать снова</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Полоска состояния</translation>
    </message>
    <message>
        <source>Load Game</source>
        <translation type="obsolete">Загрузить игру</translation>
    </message>
    <message>
        <source>Save Game</source>
        <translation type="obsolete">Сохранить игру</translation>
    </message>
    <message>
        <source>End Game</source>
        <translation type="obsolete">Завершить игру</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Невозможно загрузить тему</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Тема</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>не была успешно загружена</translation>
    </message>
    <message>
        <source>Load Scenario</source>
        <translation type="obsolete">Загрузить сценарий</translation>
    </message>
    <message>
        <source>Load Campaign</source>
        <translation type="obsolete">Загрузить кампанию</translation>
    </message>
    <message>
        <source>Load scenario</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load campaign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fill with AI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add AI player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerWidget</name>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Закончить</translation>
    </message>
</context>
</TS>
